@@ -7,7 +7,7 @@
 from winswitch.util.simple_logger import Logger
 from winswitch.util.vash_util import generate_image
 from winswitch.util.common import load_binary_file
-from winswitch.util.main_loop import loop_init, loop_run, loop_exit
+from winswitch.util.main_loop import test_loop, loop_exit
 logger=Logger("vash_util_test", log_colour=Logger.CYAN)
 
 def test_generate_image():
@@ -25,9 +25,11 @@ def test_generate_image():
 		logger.serror(None, *args)
 		loop_exit()
 
-	loop_init(False)
 	generate_image(s, filename, image_done, err)
-	loop_run()
+
+
+def main():
+	test_loop(test_generate_image)
 
 if __name__ == "__main__":
-	test_generate_image()
+	main()
