@@ -6,17 +6,9 @@
 
 from winswitch.util.simple_logger import Logger
 logger=Logger("xpra_server_test", log_colour=Logger.RED, _debug=True)
-from winswitch.util.main_loop import loop_init, loop_run, loop_exit, callLater
+from winswitch.util.main_loop import test_loop
 
-def main():
-	def start_loop():
-		logger.slog()
-		def timeout(*args):
-			loop_exit()
-		callLater(120, timeout)
-		loop_run()
-
-	loop_init(False)
+def xpra_detect():
 	from winswitch.objects.server_settings import ServerSettings
 	config = ServerSettings()
 	from winswitch.virt.xpra_server_util import XpraServerUtil
@@ -35,7 +27,10 @@ def main():
 	xss.detect_existing_sessions([])
 	xss.setup_directory_watcher()
 
-	start_loop()
+
+def main():
+	test_loop(xpra_detect)
+
 
 if __name__ == "__main__":
 	main()
