@@ -6,7 +6,7 @@
 
 import sys
 from winswitch.util.simple_logger import Logger
-from winswitch.util.simple_logger import set_log_filename, set_log_dir
+from winswitch.util.simple_logger import set_log_filename, set_log_dir, rotate_log_file
 from winswitch.util.paths import CLIENT_DIR, APPLET_LOG
 set_log_dir(CLIENT_DIR)
 set_log_filename(APPLET_LOG)
@@ -2031,6 +2031,7 @@ class WinSwitchApplet(ClientBase):
 #****************************************************************
 def main():
 	logger.slog("main")
+	exit_code = 0
 	winswitch = None
 	try:
 		winswitch = WinSwitchApplet()
@@ -2038,10 +2039,9 @@ def main():
 		logger.exc(e)
 		if winswitch:	#if we managed to load that class, display_error should have loaded too
 			display_error("%s failed to start" % APPLICATION_NAME, str(e))
-		sys.exit(1)
+		exit_code = 1
 
-	exit_code = 0
-	if not winswitch.contact_existing_client():
+	if exit_code==0 and not winswitch.contact_existing_client():
 		try:
 			winswitch.run()
 			logger.slog("run() ended")
@@ -2052,13 +2052,10 @@ def main():
 				winswitch.cleanup()
 			except Exception, e:
 				logger.serror("exception during cleanup()", e)
-		logger.slog("exit code=%d, waiting for all other threads to exit - this may take a few seconds" % exit_code)
-		dump_threads()
-	from winswitch.util.simple_logger import rotate_log_file
+	dump_threads()
+	logger.slog("main()=%s" % exit_code)
 	rotate_log_file()
 	return	exit_code
 
 if __name__ == "__main__":
-	c = main()
-	logger.slog("main()=%s" % c)
-	sys.exit(c)
+	sys.exit(main())
