@@ -6,12 +6,14 @@
 
 import sys
 from winswitch.client.client_wrapper import parse_args
+from winswitch.util.simple_logger import set_log_filename, set_log_dir
+from winswitch.util.paths import CLIENT_DIR, APPLET_LOG
 
 def main():
+	set_log_dir(CLIENT_DIR)
+	set_log_filename(APPLET_LOG)
 	if not parse_args():
 		return
-	from winswitch.util.simple_logger import rotate_log_file
-	rotate_log_file()
 	from winswitch.client.applet import main
 	code = main()
 	sys.exit(code)
