@@ -117,7 +117,6 @@ class ClientBase:
 		self.reactor_run = reactor_run
 		self.reactor_stop = reactor_stop
 		self.find_server_config_arg()
-		self.test_existing_client()
 
 	def __str__(self):
 		return	"WinSwitchClient"
@@ -173,9 +172,11 @@ class ClientBase:
 					self.start_links,					# connect to enabled servers
 					self.ready
 				]:
+			self.sdebug("calling %s" % x)
 			callFromThread(x)
 
 	def run(self):
+		self.sdebug()
 		self.register_signals()				# catch SIGINT / SIGTERM
 		#self.threaded_start()
 		thread.start_new(self.threaded_start, ())
@@ -409,6 +410,18 @@ class ClientBase:
 			return	None
 		self.settings.xkbmap_print = getkeymap("-print")
 		self.settings.xkbmap_query = getkeymap("-query")
+		if WIN32:
+			from winswitch.util.xkbmap_util import get_win32_layout
+			self.settings.xkbmap_layout, self.settings.xkbmap_variant = get_win32_layout[:2]
+		elif self.settings.xkbmap_query:
+			#find layout from setxkbmap -query output:
+			for x in self.settings.xkbmap_query.splitlines():
+				if not x:
+					continue
+				if x.startswith("layout:"):
+					self.settings.xkbmap_layout = x.split(":")[1].strip()
+					self.slog("found layout=%s" % self.settings.xkbmap_layout)
+					break
 
 	def may_populate_xmodmap(self):
 		if self.settings.custom_xmodmap_pm and self.settings.custom_xmodmap_pke:
@@ -513,13 +526,13 @@ class ClientBase:
 		except Exception, e:
 			self.serr(None, e, filename)
 
-	def test_existing_client(self):
+	def contact_existing_client(self):
 		"""
 		If an existing applet is running, just wake it up with a simple message.
 		Then close this instance as we don't want to have 2 copies running.
 		"""
 		if "--no-local-socket" in sys.argv:
-			return
+			return	False
 		client = make_local_client()
 		self.sdebug("client=%s" % client)
 		if self.server_config_filename_arg:
@@ -528,7 +541,8 @@ class ClientBase:
 			cmd = COMMAND_WAKEUP
 		if client.test_socket(cmd):
 			self.sdebug("successfully sent '%s' to existing instance" % cmd)
-			sys.exit(0)
+			return True
+		return	False
 
 	def start_local_server(self):
 		"""
@@ -589,7 +603,7 @@ class ClientBase:
 		def embedded_server_ready():
 			self.slog()
 			self.connect_to_embedded_server()
-			self.schedule_detect_local_servers()
+			self.schedule_detect_local_servers("embedded server is now ready")
 		server = WinSwitchServer(True, embedded_server_ready)
 		self.sdebug("server=%s" % server)
 		if server.check():
@@ -605,22 +619,25 @@ class ClientBase:
 				self.serr(None, e)
 			self.local_server = None
 
-	def check_local_server(self, add):
+	def check_local_server(self, add, reason):
 		"""
 		This callback is triggered when a server is removed from mDNS or the portfile disappears.
 		"""
 		if add:
-			self.schedule_detect_local_servers()
+			self.schedule_detect_local_servers(reason)
 		else:
 			self.slog("should get removed automatically..", add)
 
-	def schedule_detect_local_servers(self):
+	def schedule_detect_local_servers(self, reason=None):
 		"""
 		Schedule to run in 1 second, allows us to batch local server detection.
 		"""
-		self.sdebug("local_detect_scheduled=%s" % self.local_detect_scheduled)
-		if self.local_detect_scheduled or self.cleanup_called:
+		if self.cleanup_called:
 			return
+		if self.local_detect_scheduled:
+			self.sdebug("already scheduled", reason)
+			return
+		self.slog("scheduling", reason)
 		self.local_detect_scheduled = True
 		callLater(1, self.detect_local_servers, True)
 
@@ -735,12 +752,12 @@ class ClientBase:
 				self.local_servers_watchers[f] = monitor
 
 	def server_portfile_changed(self, monitor, file1, file2, evt_type):
-		self.slog("evt_type=%s" % type(evt_type), monitor, file1, file2, evt_type)
-		self.check_local_server(True)
+		self.sdebug("evt_type=%s" % type(evt_type), monitor, file1, file2, evt_type)
+		self.check_local_server(True, "server port file modified")
 
 	def server_dir_changed(self, monitor, d, ignored, evt_type):
-		self.slog("evt_type=%s" % type(evt_type), monitor, d, ignored, evt_type)
-		self.check_local_server(True)
+		self.sdebug("evt_type=%s" % type(evt_type), monitor, d, ignored, evt_type)
+		self.check_local_server(True, "server dir modified")
 
 	def stop_mdns_listener(self):
 		self.sdebug()
@@ -760,13 +777,15 @@ class ClientBase:
 				try:
 					from winswitch.net.avahi_listener import AvahiListener
 					self.mdns_listener = AvahiListener(MDNS_TYPE, None, self.mdns_add, self.mdns_remove)
-				except Exception, e:
-					self.serror("failed to load avahi listener", e)
+				except ImportError, e:
+					self.serror("failed to load avahi listener: %s" % e)
 			if self.mdns_listener is None:
-				from winswitch.net.twisted_bonjour_listener import TwistedBonjourListeners
-				self.mdns_listener = TwistedBonjourListeners(self.reactor, [""], MDNS_TYPE, None, self.mdns_add, self.mdns_remove)
-			self.mdns_listener.start()
-
+				try:
+					from winswitch.net.twisted_bonjour_listener import TwistedBonjourListeners
+					self.mdns_listener = TwistedBonjourListeners(self.reactor, [""], MDNS_TYPE, None, self.mdns_add, self.mdns_remove)
+				except ImportError, e:
+					self.serror("failed to load pybonjour listener: %s" % e)
+			
 			def check_mdns_data_received():
 				self.sdebug("mdns_add_count=%s" % self.mdns_add_count)
 				config = get_local_server_config(False, False, show_warnings=False, load_ssh_key=False)
@@ -795,11 +814,13 @@ class ClientBase:
 														"\nThis prevents automatic host detection.", callback=("Show mDNS Help", show_mdns_info),
 														notification_type=NOTIFY_ERROR)
 
-			#figure out if we expect to receive at least one multicast entry from our local serve:
-			if self.settings.start_local_server:
-				""" run the checks in 30s, giving enough time for the server to startup,
-					create its id and start publishing its mDNS record: """
-				callLater(30, check_mdns_data_received)
+			if self.mdns_listener:
+				self.mdns_listener.start()
+				#figure out if we expect to receive at least one multicast entry from our local serve:
+				if self.settings.start_local_server:
+					""" run the checks in 30s, giving enough time for the server to startup,
+						create its id and start publishing its mDNS record: """
+					callLater(30, check_mdns_data_received)
 		except Exception, e:
 			self.serr(None, e)
 
@@ -1042,7 +1063,7 @@ class ClientBase:
 
 	def do_close_all_sessions(self, server):
 		self.slog(None, server)
-		for session in server.get_live_sessions():
+		for session in server.get_live_sessions(allow_preload=True):
 			self.do_close_session(server, session)
 
 	def do_close_session(self, server, session):
@@ -1086,7 +1107,7 @@ class ClientBase:
 				self.exc(e)
 
 	def do_detach_all_sessions(self, server):
-		live = server.get_live_sessions()
+		live = server.get_live_sessions(allow_preload=True)
 		self.slog("live sessions=%s" % csv_list(live), server)
 		for session in live:
 			try:
