@@ -334,7 +334,9 @@ class ProtocolHandler:
 							user.gstaudio_codecs, user.gstvideo_codecs,
                             user.open_urls, user.open_files,
 							user.client_type,
-							user.supports_virtualbox
+							user.supports_virtualbox,
+							self.binencode(user.xkbmap_query),
+                            user.xkbmap_layout, user.xkbmap_variant,
 							])
 
 	def send_remove_user(self, uuid):
@@ -450,7 +452,7 @@ class ProtocolHandler:
 	def send_tunnel_ports(self, samba_port, ipp_port):
 		self.send(SET_TUNNEL_PORTS, [samba_port, ipp_port])
 
-	def send_xmodmap(self, xmodmap_key_data, xmodmap_mod_data):
+	def send_xmodmap(self, xmodmap_key_data, xmodmap_mod_data, xkbmap_print, xkbmap_query, xkbmap_layout, xkbmap_variant):
 		enc_key_data = ""
 		if xmodmap_key_data:
 			enc_key_data = self.binencode(xmodmap_key_data)
@@ -460,6 +462,11 @@ class ProtocolHandler:
 			if xmodmap_key_data:
 				enc_mod_data = self.binencode(xmodmap_mod_data)
 			packet.append(enc_mod_data)
+		if self.remote_app_version>=[0,12,16]:
+			packet.append(self.binencode(xkbmap_print))
+			packet.append(self.binencode(xkbmap_query))
+			packet.append(xkbmap_layout)
+			packet.append(xkbmap_variant)
 		self.send(SET_XMODMAP, packet)
 
 	def send_mount_point(self, protocol, namespace, host, port, path, fs_type, auth_mode, username, password, comment, options):
@@ -583,7 +590,7 @@ class ProtocolHandler:
 			try:
 				user.xkbmap_print = bindecode(args[25])
 			except Exception, e:
-				self.serror("error parsing xkbmap data=%s : %s" % (visible_command(args[25]), e), *args)
+				self.serror("error parsing xkbmap print data=%s : %s" % (visible_command(args[25]), e), *args)
 		if len(args)>26:
 			enc = parse_csv(args[26])
 			if len(enc)>0:
@@ -602,6 +609,15 @@ class ProtocolHandler:
 		if len(args)>31:
 			user.client_type = args[31]
 		user.supports_virtualbox = len(args)>32 and get_bool(args[32])
+		if len(args)>33:
+			try:
+				user.xkbmap_query = bindecode(args[33])
+			except Exception, e:
+				self.serror("error parsing xkbmap query data=%s : %s" % (visible_command(args[33]), e), *args)
+		if len(args)>34:
+			self.xkbmap_layout = args[34]
+		if len(args)>35:
+			self.xkbmap_variant = args[35]
 		return user
 
 	def do_add_user(self, *args):
