@@ -109,7 +109,7 @@ class ServerSession(Session):
 				try:
 					from winswitch.util.process_util import send_kill_signal
 					pid_int = int(pid)
-					send_kill_signal(pid_int)
+					send_kill_signal(pid_int, may_be_missing=True)
 				except Exception, e:
 					se = str(e)
 					if se.endswith("No such process"):
