@@ -11,14 +11,14 @@ import subprocess
 from winswitch.objects.server_base import ServerBase
 from winswitch.objects.server_command import ServerCommand
 from winswitch.objects.session import ALLOW_SSH_DESKTOP_MODE
-from winswitch.util.paths import HOST_PUBLIC_KEY_FILE, DEVILSPIE_VNC_CONFIG, DESKTOP_BACKGROUND, WINSWITCH_SHARE_DIR, APP_DIR, WINSWITCH_LIBEXEC_DIR, ETC_SEARCH_ORDER, BIN_SEARCH_ORDER, XORG_XDUMMY_XPRA_CONFIG
-from winswitch.util.common import is_valid_file, is_valid_exe, is_suid, get_xpra_version, do_check_xpra_version_string, get_platform_detail, get_os_version, has_unix_group, CAN_USE_GIO, load_binary_file, is_valid_dir, generate_UUID
+from winswitch.util.paths import HOST_PUBLIC_KEY_FILE, DEVILSPIE_VNC_CONFIG, DESKTOP_BACKGROUND, WINSWITCH_SHARE_DIR, APP_DIR, WINSWITCH_LIBEXEC_DIR, ETC_SEARCH_ORDER
+from winswitch.util.common import is_valid_file, is_valid_exe, get_xpra_version, do_check_xpra_version_string, get_platform_detail, get_os_version, has_unix_group, CAN_USE_GIO, load_binary_file, is_valid_dir, generate_UUID
 from winswitch.consts import DEFAULT_FIXED_SERVER_PORT, XVNC_TIGER, XVNC_TIGHT, DEFAULT_IGNORED_COMMANDS, DEFAULT_IGNORED_XSESSIONS, DEFAULT_RDP_PORT, BINASCII, BASE64
 from winswitch.globals import WIN32, OSX
 from winswitch.util.gstreamer_util import get_default_gst_sound_sink_module, get_default_gst_sound_sink_options, get_default_gst_sound_source_module, \
 					get_default_gst_sound_source_options, get_default_gst_video_source_module, has_tcp_plugins, AUTO_SINK, AUTO_SOURCE, \
 					supported_gstaudio_codecs, supported_gstvideo_codecs
-from winswitch.util.commands_util import XPRA_COMMAND, XVFB_COMMAND, XVNC_COMMAND, XNEST_COMMAND, WINVNC_COMMAND, \
+from winswitch.util.commands_util import XPRA_COMMAND, XVNC_COMMAND, XNEST_COMMAND, WINVNC_COMMAND, \
 	VNCSHADOW_COMMAND, NXAGENT_COMMAND, VNCCONFIG_COMMAND, VNCPASSWD_COMMAND, \
 	PULSEAUDIO_COMMAND, DEVILSPIE_COMMAND, XLOADIMAGE_COMMAND, XSET_COMMAND, SCREEN_COMMAND, VIRSH_COMMAND, VBOXMANAGE_COMMAND, VBOXHEADLESS_COMMAND, \
 	XWD_COMMAND, PNMTOPNG_COMMAND, XWDTOPNM_COMMAND, IMPORT_COMMAND, CUPSD_COMMAND, GNOME_KEYRING_DAEMON_COMMAND, \
@@ -169,56 +169,6 @@ def get_default_ssh_host_public_key_file():
 					return filename
 	return	""
 
-XPRA_XVFB_COMMAND = "%s +extension Composite -screen 0 3840x2560x24+32 -nolisten tcp -noreset -auth $XAUTHORITY"
-XPRA_XORG_COMMAND = "%s -nolisten tcp +extension GLX +extension RANDR +extension RENDER -logfile ${logfile} -config %s"
-XORG_VERSION_LINE = "X.Org X Server "
-MIN_XORG_VERSION = [1,12,0]
-def get_default_xpra_Xvfb_command(skip_detection):
-	config = os.path.join(WINSWITCH_SHARE_DIR, XORG_XDUMMY_XPRA_CONFIG)
-	if not is_valid_file(config):
-		if not WIN32 and not OSX:
-			logger.serror("cannot find Xorg Xdummy Xpra config in %s, check your installation!" % config)
-		skip_detection = True
-	if not skip_detection and not WIN32 and not OSX:
-		# try to figure out if Xorg is usable
-		# we need one that is NOT suid and is recent enough...
-		for bin_dir in BIN_SEARCH_ORDER:
-			for command in ["X", "Xorg", "Xdummy"]:
-				cmd = os.path.join(bin_dir, command)
-				if not is_valid_exe(cmd):
-					continue
-				if is_suid(cmd):
-					logger.slog("cannot use X binary in %s as it is suid" % cmd)
-					continue
-				logger.sdebug("found X binary in %s, checking version" % cmd)
-				cmd = [cmd, "-version"]
-				try:
-					proc = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-					(out, _) = proc.communicate()
-					code = proc.returncode
-				except Exception, e:
-					logger.serror("failed to execute cmd='%s': %s" % (cmd, e), skip_detection)
-					continue
-
-				if code!=0:
-					logger.slog("X binary in %s does not respond to '-version' argument, ignoring it" % cmd)
-					continue
-				for x in out.splitlines():
-					if x.startswith(XORG_VERSION_LINE):
-						v = x[len(XORG_VERSION_LINE):]
-						logger.sdebug("found X binary in %s with version=%s" % (cmd, v))
-						try:
-							version = [int(x) for x in v.split(".")]
-							if version<MIN_XORG_VERSION:
-								logger.slog("X binary in %s is too old: %s (%s minimum required)" % (cmd, version, MIN_XORG_VERSION))
-								continue
-							logger.slog("found valid X binary version %s in %s" % (version, cmd))
-							return	XPRA_XORG_COMMAND % (cmd, config)
-						except Exception, e:
-							logger.serr("failed to parse version: %s" % v, e)
-							break;
-	#when all else fails, use default Xvfb
-	return XPRA_XVFB_COMMAND % XVFB_COMMAND
 
 
 
@@ -302,8 +252,6 @@ class ServerSettings(ServerBase):
 			"clients_can_stop",
 			"# Xnest is used for simulating desktop mode with xpra and ssh:",
 			"xnest_command",
-			"# Xvfb is required by xpra:",
-			"xpra_xvfb_command",
 			"# SMB commands used for mounting and unmounting:",
 			"smbmount_command", "smbumount_command",
 			"# to capture screenshots:",
@@ -371,7 +319,6 @@ class ServerSettings(ServerBase):
 
 		self.dbus_command = "dbus-daemon --fork --print-address=1 --print-pid=1 --session"
 
-		self.xpra_xvfb_command = get_default_xpra_Xvfb_command(skip_detection)
 		self.nxagent_command = NXAGENT_COMMAND
 		self.pulseaudio_command = PULSEAUDIO_COMMAND
 		self.xpra_command = XPRA_COMMAND
@@ -474,7 +421,7 @@ class ServerSettings(ServerBase):
 
 	def test_supports_xpra(self):
 		""" xpra requires the xpra_command and xvfb_command, does not work on win32 (and never will natively) or OSX (not yet?) """
-		return	not OSX and not WIN32 and is_valid_exe(self.xpra_command) and is_valid_exe(self.xpra_xvfb_command)
+		return	not OSX and not WIN32 and is_valid_exe(self.xpra_command)
 
 	def test_supports_nx(self):
 		""" NX does not word on windows or osx: """
@@ -512,15 +459,17 @@ class ServerSettings(ServerBase):
 		sshd = which_extra(["/usr/sbin", "/usr/local/sbin"], "sshd")
 		code = -1
 		sshd_config = ""
-		if is_valid_file(sshd):
-			cmd = [sshd, "-T"]
-			try:
-				proc = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-				(sshd_config, _) = proc.communicate()
-				code = proc.returncode
-			except Exception, e:
-				self.serr("failed to run '%s'" % cmd, e)
-				code = -1
+		if not is_valid_file(sshd):
+			self.serror("cannot find sshd, assuming that ssh is not installed and X11 forwarding cannot work")
+			return	False
+		cmd = [sshd, "-T"]
+		try:
+			proc = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+			(sshd_config, _) = proc.communicate()
+			code = proc.returncode
+		except Exception, e:
+			self.serr("failed to run '%s'" % cmd, e)
+			code = -1
 		if code!=0 or (sshd_config and sshd_config.endswith("Permission denied")):
 			self.serror("cannot run 'sshd -T' to verify: '%s', assuming X11 Forwarding is enabled!" % sshd_config)
 			return	True
