@@ -9,14 +9,42 @@ import thread
 
 from winswitch.consts import MAX_SCREENSHOT_WIDTH, MAX_SCREENSHOT_HEIGHT
 from winswitch.globals import OSX, WIN32
-from winswitch.util.common import is_valid_file, load_binary_file, delete_if_exists, is_our_display
+from winswitch.util.commands_util import which
+from winswitch.util.common import is_valid_file, is_valid_exe, load_binary_file, delete_if_exists, is_our_display
 from winswitch.util.simple_logger import Logger
 from winswitch.util.main_loop import callFromThread, callLater
 
+logger = Logger("capture_util", log_colour=Logger.HIGHLIGHTED_BROWN)
+
 DEBUG_DISPLAY_ACCESS = False
 NO_CAPTURE_COMMAND_WARNING_SHOWN = False
 
 
+def warn_cannot_capture(cmd):
+	global NO_CAPTURE_COMMAND_WARNING_SHOWN
+	actual_command = cmd
+	assert not WIN32
+	if cmd is not None:
+		try:
+			if type(cmd)==list:
+				actual_command = which(cmd[0])
+			elif type(cmd)==str:
+				actual_command = which(cmd.split()[0])
+			else:
+				actual_command = cmd	#hope for the best!
+		except:
+			pass
+	if not is_valid_exe(actual_command):
+		err = "screen_capture_command '%s' is not defined or invalid!" % str(cmd)
+		if not NO_CAPTURE_COMMAND_WARNING_SHOWN:
+			logger.serror(err)
+			NO_CAPTURE_COMMAND_WARNING_SHOWN = True
+		else:
+			logger.sdebug(err)
+		return err
+	NO_CAPTURE_COMMAND_WARNING_SHOWN = False
+	return None
+
 
 def screen_capture(screen_capture_command, display, env, filename, ok_callback, err_callback):
 	""" Take a screenshot of the given display, resizing it to a thumbnail stored in filename.
@@ -31,10 +59,9 @@ def screen_capture(screen_capture_command, display, env, filename, ok_callback,
 			c = ExecCaptureDisplay(screen_capture_command, display, env, filename, ok_callback, err_callback)
 		c.capture()
 	except Exception, e:
-		logger = Logger("capture_util", log_colour=Logger.HIGHLIGHTED_BROWN)
 		logger.serr(None, e, display, filename)
 		err_callback("exception: %s" % e)
-		return	None
+		return
 
 
 
@@ -118,17 +145,14 @@ class ExecCaptureDisplay(ScreenCapture):
 		ScreenCapture.__init__(self, display, env, filename, ok_callback, err_callback, False)
 		self.screen_capture_command = screen_capture_command
 
-	def do_capture(self):
-		global NO_CAPTURE_COMMAND_WARNING_SHOWN
-		if not self.screen_capture_command:
-			err = "screen_capture_command is not defined!"
-			if not NO_CAPTURE_COMMAND_WARNING_SHOWN:
-				self.serror(err)
-				NO_CAPTURE_COMMAND_WARNING_SHOWN = True
-			else:
-				self.sdebug(err)
+	def capture(self):
+		err = warn_cannot_capture(self.screen_capture_command)
+		if err:
 			self.err_callback(err)
-		NO_CAPTURE_COMMAND_WARNING_SHOWN = False
+			return
+		ScreenCapture.capture(self)
+
+	def do_capture(self):
 		cmd = ["sh", "-c", "%s%s" % (self.screen_capture_command, self.filename)]
 		self.exec_capture(cmd)
 
