@@ -20,8 +20,8 @@ import gobject
 
 debug_import("consts")
 from winswitch.consts import APPLICATION_NAME, AVATAR_ICON_SIZE, SPEEDS, SPEED_NAMES, DEFAULT_INTERNET_SPEED, DEFAULT_LAN_SPEED, MINIMUM_LAN_SPEED, MENU_SIZES, \
-		XPRA_TYPE, NX_TYPE, SCREEN_TYPE, SSH_TYPE, VNC_TYPE, WINDOWS_TYPE, PROTOCOLS_DOC_URL, \
-		OPEN_LOCALLY, OPEN_NEW_SESSION, OPEN_EXISTING_SESSION
+		XPRA_TYPE, NX_TYPE, SCREEN_TYPE, SSH_TYPE, VNC_TYPE, WINDOWS_TYPE, VIRTUALBOX_TYPE, GSTVIDEO_TYPE, TYPE_NAMES, \
+		PROTOCOLS_DOC_URL, OPEN_LOCALLY, OPEN_NEW_SESSION, OPEN_EXISTING_SESSION
 debug_import("globals")
 from winswitch.globals import WIN32, OSX
 debug_import("commands_util")
@@ -93,6 +93,15 @@ class ConfigureAppletWindow(TabbedConfigureWindow):
 	def add_file_select(self, table, name, patterns, any_file=True, x_factor=1):
 		return	add_tableline(self, table, "%s Tool" % name, file_select(name, patterns, any_file), "Location of the %s tool binary program" % name, x_factor=x_factor)
 
+	def make_protocol_icon_label_box(self, session_type):
+		label_box = gtk.HBox(False, 12)
+		enable_label = self.ui_util.make_label(TYPE_NAMES.get(session_type))
+		proto_image = gtk.Image()
+		proto_image.set_from_pixbuf(self.ui_util.scale_icon(icons.get(session_type), 16))
+		label_box.pack_start(proto_image)
+		label_box.pack_start(enable_label)
+		return label_box
+
 	def add_protocol_file_select(self, table, session_type, name, patterns, any_file=True, tool_name=None, x_offset=0, x_factor=1, row_inc=True):
 		dh = get_distro_helper()
 		install_command = dh.get_install_action(session_type)
@@ -146,7 +155,8 @@ class ConfigureAppletWindow(TabbedConfigureWindow):
 		if help_url:
 			box.pack_start(self.make_help_url_button("About %s" % name, help_url))
 		enable_label = self.ui_util.make_label("%s Mode" % name)
-		add_tableline(self, table, enable_label, box, "Enable %s mode" % name, x_offset=x_offset, entry_x_factor=3, row_inc=row_inc)
+		label_box = self.make_protocol_icon_label_box(session_type)
+		add_tableline(self, table, label_box, box, "Enable %s mode" % name, x_offset=x_offset, entry_x_factor=3, row_inc=row_inc)
 		set_file_select_change_cb(file_entry, file_input_changed)
 		return	(enable_label, enable_button, file_entry)
 
@@ -339,12 +349,14 @@ class ConfigureAppletWindow(TabbedConfigureWindow):
 		self.gstvideo_enabled = gtk.CheckButton()
 		gst_box.add(self.gstvideo_enabled)
 		gst_box.add(self.make_help_url_button("About GStreamer", self.protocol_help_url("gstreamer")))
-		(self.gstvideo_label, _) = add_tableline(self, table, "GStreamer Video", gst_box, row_inc=False)
+		gstreamer_label_box = self.make_protocol_icon_label_box(GSTVIDEO_TYPE)
+		(self.gstvideo_label, _) = add_tableline(self, table, gstreamer_label_box, gst_box, row_inc=False)
 		vbox_box = gtk.HBox()
 		self.virtualbox_enabled = gtk.CheckButton()
 		vbox_box.add(self.virtualbox_enabled)
 		vbox_box.add(self.make_help_url_button("About VirtualBox", self.protocol_help_url("virtualbox")))
-		(self.virtualbox_label, _) = add_tableline(self, table, "VirtualBox", vbox_box, x_offset=2)
+		virtualbox_label_box = self.make_protocol_icon_label_box(VIRTUALBOX_TYPE)
+		(self.virtualbox_label, _) = add_tableline(self, table, virtualbox_label_box, vbox_box, x_offset=2)
 		(_, self.xpra_enabled, self.xpra_entry) = self.add_protocol_file_select(table, XPRA_TYPE, "Xpra", ["xpra.exe", "xpra*.exe", "xpra.bat"], x_factor=2)
 		(_, self.nx_enabled, self.nxproxy_entry) = self.add_protocol_file_select(table, NX_TYPE, "NX Proxy", ["nxproxy.exe", "nx*.exe"], x_factor=2)
 		(_, self.vnc_enabled, self.vnc_entry) = self.add_protocol_file_select(table, VNC_TYPE, "VNC Viewer", ["vncviewer.exe", "vnc*.exe"], x_factor=2)
