@@ -453,7 +453,7 @@ class UI_Util:
 				comments += " (release build)"
 			else:
 				comments += " (beta build)"
-			if LOCAL_MODIFICATIONS==0:
+			if int(LOCAL_MODIFICATIONS)==0:
 				comments += "\n(svn revision %s)" % REVISION
 			else:
 				comments += "\n(svn revision %s with %s local changes)" % (REVISION, LOCAL_MODIFICATIONS)
