@@ -60,6 +60,7 @@ XDG_MIME_COMMAND = ""
 CUPSD_COMMAND = ""
 GNOME_KEYRING_DAEMON_COMMAND = ""
 XSCREENSAVER_COMMAND_COMMAND = ""
+SELINUXENABLED_COMMAND = ""
 # these are in libexec on *nix:
 GST_CAPTURE_COMMAND = ""
 GST_PLAYBACK_COMMAND = ""
@@ -161,6 +162,7 @@ else:
 	CUPSD_COMMAND = which("cupsd")
 	GNOME_KEYRING_DAEMON_COMMAND = which("gnome-keyring-daemon")
 	XSCREENSAVER_COMMAND_COMMAND = which("xscreensaver-command")
+	SELINUXENABLED_COMMAND = which("selinuxenabled")
 
 
 def do_get_xvnc_type(path):
