@@ -423,10 +423,10 @@ def get_as_root_list():
 
 def xpra_path_workaround():
 	if os.name=="posix":
-		#debian does weird things:
+		#debian does some really weird and infuriating things:
 		debian_xpra = os.path.join("/usr", "lib", "xpra")
 		if is_valid_dir(debian_xpra) and debian_xpra not in sys.path:
-			sys.path.insert(0, debian_xpra)
+			sys.path.insert(0, os.path.join("/usr", "lib"))
 
 def get_xpra_version(xpra_command):
 	#can't parse xpra command output as we use a gui wrapper on win32 and osx
