@@ -8,6 +8,14 @@
 from winswitch.util.process_util import exec_nopipe
 from winswitch.util.simple_logger import Logger
 
+firewall_util = None
+def get_firewall_util(config):
+	global firewall_util
+	if firewall_util is None:
+		firewall_util = FirewallUtil(config)
+	return firewall_util
+
+
 class	FirewallUtil:
 	def	__init__(self, config):
 		Logger(self, log_colour=Logger.CYAN)
