@@ -538,21 +538,26 @@ def win32_TerminateProcess(pid):
 		return	False
 
 
-def send_kill_signal(pid, kill_signal=signal.SIGTERM):
-	global no_oskill_warned
-	logger.slog(None, pid, kill_signal)
+def send_kill_signal(pid, kill_signal=signal.SIGTERM, may_be_missing=False):
+	logger.slog(None, pid, kill_signal, may_be_missing)
 	if pid is None or pid<1:
 		return False
 
 	#only supported on win32 since Python 2.7
 	if hasattr(os, "kill"):
-		logger.sdebug("using os.kill", pid, kill_signal)
+		logger.sdebug("using os.kill", pid, kill_signal, may_be_missing)
+		e = None
 		try:
 			os.kill(pid , kill_signal)
 			return	True
+		except OSError, e:
+			if may_be_missing and str(e).find("No such process")>=0:
+				logger.sdebug("%s" % e, pid, kill_signal)
+				return False
 		except Exception, e:
-			logger.serror("%s" % e, pid, kill_signal)
-			return False
+			pass
+		logger.serror("%s" % e, pid, kill_signal, may_be_missing)
+		return False
 	elif WIN32:
 		return win32_TerminateProcess(pid)
 	else:
