@@ -4,9 +4,12 @@
 # Copyright (c) 2009-2012 Antoine Martin <antoine@nagafix.co.uk>
 # Window-Switch is released under the terms of the GNU GPL v3
 
+
+from winswitch.util.main_loop import with_loop, loop_exit
 from winswitch.util.simple_logger import Logger
 from winswitch.util.process_util import twisted_exec
-from winswitch.util.common import no_newlines
+from winswitch.util.common import no_newlines, is_valid_exe
+from winswitch.util.commands_util import SELINUXENABLED_COMMAND
 
 logger=Logger("selinux_util", log_colour=Logger.CYAN)
 
@@ -48,6 +51,9 @@ def check_selinux(result_callback):
 		except Exception, e:
 			logger.serr(None, e, enabled, enforcing, warn, info)
 
+	if not is_valid_exe(SELINUXENABLED_COMMAND):
+		cache_result(False, False, False, SELINUX_DISABLED)
+		return
 
 	def selinux_warn(messages):
 		logger.slog("******************************* WARNING! ********************************")
@@ -90,15 +96,13 @@ def check_selinux(result_callback):
 	twisted_exec(["selinuxenabled"], selinuxenabled_ok, selinuxenabled_err)
 
 
-#****************************************************************
 def main():
-	from winswitch.util.main_loop import loop_init, loop_run, loop_exit
 	def result_callback(selinux_enabled, selinux_enforcing, warning_bool, info):
 		logger.slog(None, selinux_enabled, selinux_enforcing, warning_bool, info)
 		loop_exit()
-	loop_init(False)
-	check_selinux(result_callback)
-	loop_run()
+	def check():
+		check_selinux(result_callback)
+	with_loop(check)
 
 if __name__ == "__main__":
 	main()
