@@ -122,8 +122,8 @@ def rotate_log_file():
 				archive_path = get_log_filename(logdir, OLD_LOG)
 				os.rename(log_filepath, archive_path)
 				log_filepath = None
-		except:
-			pass
+		except Exception, e:
+			print("failed to rotate log file: %s" % e)
 	finally:
 		lock.release()
 	
@@ -152,7 +152,7 @@ def set_log_to_buffer(enabled):
 
 def make_timestamp():
 	if log_datetime:
-		return	datetime.datetime.now().strftime("%Y/%d/%m %H:%M:%S ")
+		return	datetime.datetime.now().strftime("%Y/%d/%m %H:%M:%S.%f ")
 	return	""
 
 
