@@ -136,12 +136,6 @@ class	ClientUtilBase:
 	def handle_session_event(self, servers, event, name):
 		self.last_session_event = event
 
-	def add_default_options_values(self, options, server, server_command):
-		"""
-		Add default options without asking the user
-		"""
-
-
 	def get_options_widgets(self, server, server_command, shadowed_session=None, current_options=None, default_options=None, change_cb=None):
 		"""
 		Can be used by subclasses to add widgets to start/edit session screens.
@@ -231,6 +225,8 @@ class	ClientUtilBase:
 
 	def	client_start_session(self, server, client, command, screen_size, opts):
 		# ask the server to start it:
+		if opts is None:
+			opts = self.get_default_options()
 		client.start_session(command.uuid, self.session_type, screen_size, opts)
 
 	def attach(self, server, session, host, port):
@@ -363,6 +359,7 @@ class	ClientUtilBase:
 			session.client_start_time = time.time()
 			save_client_pid(session)
 			def close_session_detach_client():
+				self.sdebug()
 				self.client_detach_session(server, None, session)
 			session.add_status_update_callback(None, Session.STATUS_CLOSED, close_session_detach_client, clear_it=True, timeout=None)
 			if onstart_status and session.status!=Session.STATUS_CLOSED:
@@ -381,7 +378,7 @@ class	ClientUtilBase:
 					session.touch()
 
 		def ended(line_process):
-			self.slog(None, line_process)
+			self.slog("session=%s, kill_client=%s" % (session, session.kill_client), line_process)
 			if line_process in session.processes:
 				session.processes.remove(process)
 			if line_process in self.line_processes:
@@ -459,8 +456,9 @@ class	ClientUtilBase:
 		assert WIN32
 		def Xming_ready(local_display, display_process):
 			self.slog("session=%s" % session, local_display, display_process)
-			(session.local_display, session.local_display_process) = (local_display, display_process)
-			if session.local_display_process!=self.xming_util.shared_display:
+			session.local_display, session.local_display_process = local_display, display_process
+			if local_display!=self.xming_util.shared_display:
+				self.slog("not a shared display - adding to processes list", local_display, display_process)
 				session.processes.append(session.local_display_process)				#only stop the display if it is not shared
 			ready_cb()
 		def Xming_err(err):
