@@ -249,10 +249,17 @@ class	LocalX11ServerUtil(ServerUtilBase):
 		session.start_time = start_time
 		session.command = self.get_display_command(display, pid)
 		session.set_window_icon_data(self.get_display_icon_data(session.command))
-		if display_no==0:
-			session.name = self.display0_session_name
-		else:
-			session.name = self.display_session_name_prefix + str(display)
+		try:
+			import pwd
+			name = pwd.getpwnam(username).pw_gecos
+			if not name:
+				name = username
+			session.name = "%s' Desktop" % name
+		except:
+			if display_no==0:
+				session.name = self.display0_session_name
+			else:
+				session.name = self.display_session_name_prefix + str(display)
 		session.owner = self.get_local_display_owner(display)
 		session.actor = session.owner
 		session.full_desktop = True
@@ -282,7 +289,8 @@ class	LocalX11ServerUtil(ServerUtilBase):
 		return	session
 
 
-def main():
+def detect():
+	from winswitch.util.main_loop import loop_exit
 	from winswitch.objects.server_settings import ServerSettings
 	from winswitch.util.config import get_local_server_config
 	from winswitch.util.simple_logger import Logger
@@ -292,6 +300,12 @@ def main():
 		logger.sdebug("start_time=%s (%s seconds ago), command=%s" % (session.start_time, time.time()-session.start_time, session.command), session)
 	lx11 = LocalX11ServerUtil(ss, add_session, None, None, None)
 	lx11.detect_local_displays()
+	loop_exit()
+
+def main():
+	from winswitch.util.main_loop import test_loop
+	test_loop(detect)
+
 
 if __name__ == "__main__":
 	main()
