@@ -103,7 +103,11 @@ class	NXClientBase(ClientUtilBase):
 			nx_options["cookie"] = session.password
 		#keyboard undocumented NX magic:
 		rules = "evdev"
-		layout = self.settings.xkbmap_layout or "us"
+		if self.settings.xkbmap_layout:
+			#trim extra layouts, ie: fr_CH,us -> fr
+			layout = self.settings.xkbmap_layout.split(",")[0].split("_")[0]
+		else:
+			layout = "us"
 		if WIN32:
 			rules = "pc105"
 		nx_options["keyboard"] = "%s/%s" % (rules, layout)
