@@ -126,7 +126,7 @@ class	NXServerUtil(ServerUtilBase):
 	def kill_watchdog(self, session, match):
 		self.slog("pid=%s" % session.watchdog_pid, session, match)
 		if session.watchdog_pid:
-			send_kill_signal(session.server_process_pid)
+			send_kill_signal(session.watchdog_pid)
 		return	None	#	Session.STATUS_CLOSED
 
 	def nxagent_sighup(self, session):
@@ -160,6 +160,7 @@ class	NXServerUtil(ServerUtilBase):
 			self.nxagent_sighup(session)
 		else:
 			def suspended_sighup_nxagent():
+				self.slog()
 				self.nxagent_sighup(session)
 			session.add_status_update_callback(None, Session.STATUS_SUSPENDED, suspended_sighup_nxagent)
 
