@@ -4,6 +4,7 @@
 # Copyright (c) 2009-2012 Antoine Martin <antoine@nagafix.co.uk>
 # Window-Switch is released under the terms of the GNU GPL v3
 
+import signal
 import os
 import re
 import shutil
@@ -28,14 +29,16 @@ from winswitch.util.file_io import get_session_snapshot_filename, get_session_fi
 	get_session_wrapper_log_filename, get_session_pulseaudio_log_filename, get_session_xauth_filename, get_server_session_dir, \
 	get_session_cupsd_config_filename, get_session_cupsd_socket_filename, get_session_cupsd_temp_dir, get_session_cupsd_log_filename, \
 	mksubdir, RWX
-from winswitch.util.firewall_util import FirewallUtil
+from winswitch.util.firewall_util import get_firewall_util
 from winswitch.util.icon_cache import guess_icon_from_name
-from winswitch.util.process_util import exec_nopipe, kill_pid, kill0
+from winswitch.util.process_util import exec_nopipe, kill0, send_kill_signal
 from winswitch.util.simple_logger import Logger, msig
+from winswitch.virt.options_common import LOCALE
 from winswitch.virt.virt_server_daemonizer import start_daemon
 from winswitch.virt.display_util import DisplayUtil
 from winswitch.util.xmodmap_util import set_xmodmap
-from winswitch.util.commands_util import XDG_OPEN_COMMAND
+from winswitch.util.xkbmap_util import set_keymap
+from winswitch.util.commands_util import XDG_OPEN_COMMAND, XSCREENSAVER_COMMAND_COMMAND
 from winswitch.util.paths import WINSWITCH_LIBEXEC_DIR, GNOME_SETTINGS_DAEMON
 from winswitch.util.main_loop import callLater, callFromThread
 
@@ -57,17 +60,17 @@ class	ServerUtilBase(DisplayUtil):
 		self.update_session_status = update_session_status
 		self.session_failed = session_failed
 
-		self.read_lock = threading.Lock()
 		self.lock = threading.Lock()
 
 		self.bind_to_all_interfaces = True
 		self.dbus_enabled = not WIN32 and not OSX
 		self.disable_gnome_screensaver = self.dbus_enabled
+		self.disable_xscreensaver = True
 		self.gnome_settings_daemon_enabled = not WIN32 and not OSX and is_valid_file(GNOME_SETTINGS_DAEMON)
 		self.orbit_socket_dir_enabled = not WIN32 and not OSX
 		self.use_global_xauth = True
 
-		self.ignored_options_for_compare = []		# list of options which may differ and the pre-loaded session will still be accepted
+		self.ignored_options_for_compare = [LOCALE]		# list of options which may differ and the pre-loaded session will still be accepted
 		self.test_using_sockets = False
 		self.session_start_timeout = 30
 		self.prelaunch_enabled = self.config.prelaunch_enabled
@@ -76,18 +79,16 @@ class	ServerUtilBase(DisplayUtil):
 		self.shadow_start_timeout = 10				#how long to wait for shadow sessions to start
 		self.connecting_timeout = 0					#dont timeout automatically, if set it will check after the delay to prevent session stuck in connecting state
 		self.port_mapper = get_port_mapper()
-		self.firewall_util = FirewallUtil(self.config)
+		self.firewall_util = get_firewall_util(self.config)
 		self.local_users = []						#list of xpra users (which we may preload sessions for)
 		self.watched_directories = []
 		self.batch_detect_sessions_delay = 0.1		#how long do we batch for
 		self.detect_pending = False
 		self.filechange_monitors = {}
 		self.init_done = False
-		self.last_line = None
 		self.debug_log_read = False
-		self.log_buffer = ""
 		self.selinux_enforcing = False
-		self.enabled = True
+		self.enabled = ("--no-%s" % self.session_type) not in sys.argv
 
 	def get_config_options_base(self, detect=False, log=False, start=False, add_desktop_session_options=False):
 		options = ["# support for %s sessions:" % self.session_type, "enabled",
@@ -106,8 +107,9 @@ class	ServerUtilBase(DisplayUtil):
 					"bind_to_all_interfaces",
 					"# start a dbus instance for each session",
 					"dbus_enabled",
-					"# disable the gnome screensaver after starting sessions",
+					"# disable screensavers after starting sessions",
 					"disable_gnome_screensaver",
+					"disable_xscreensaver",
 					"# start (and more importantly stop) the gnome settings daemon ourselves",
 					"gnome_settings_daemon_enabled",
 					"# define a new ORBIT_SOCKETDIR for each session",
@@ -118,7 +120,7 @@ class	ServerUtilBase(DisplayUtil):
 
 	def get_config_options(self):
 		options = self.get_config_options_base(True, True, True, True)
-		# "prelaunch_enabled", "max_prelaunch_failures", "session_start_timeout" 
+		# "prelaunch_enabled", "max_prelaunch_failures", "session_start_timeout"
 		return	options
 
 	def load_config(self):
@@ -128,6 +130,7 @@ class	ServerUtilBase(DisplayUtil):
 			props = load_properties(filename)
 			populate_object_from_properties(props, self, type(self), keys_in=options, warn_on_missing_keys=True, warn_on_extra_keys=True)
 		else:
+			#create the initial config
 			props = {}
 			for option in options:
 				if option.startswith("#"):
@@ -144,8 +147,7 @@ class	ServerUtilBase(DisplayUtil):
 		self.init_done = True
 
 	def do_init(self):
-		self.start_prelaunch()
-
+		pass
 
 	def get_local_client_ID(self):
 		# get the ID from the local client config file
@@ -289,8 +291,12 @@ class	ServerUtilBase(DisplayUtil):
 	def use_gio(self, session):
 		return CAN_USE_GIO and not sys.platform.startswith("freebsd")
 
+	def stop_watching_logfile(self, session):
+		if session.log_watcher_cancel and not session.log_watcher_cancel.is_cancelled():
+			session.log_watcher_cancel.cancel()
+
 	def do_watch_session_log(self, logfilename, logfile, session):
-		# watch file for changes
+		# watch log file for changes
 		use_gio = self.use_gio(session)
 		if use_gio:
 			self.sdebug("will use gio to monitor for changes", logfilename, logfile, session)
@@ -304,16 +310,34 @@ class	ServerUtilBase(DisplayUtil):
 			mfile.connect("changed", session_logfile_changed)
 			session.log_watcher = mfile
 			self.slog("watching log with gio: %s" % mfile, logfilename, logfile, session)
-			session.read_pending = False
 		else:
 			self.slog("gio unavailable or disabled, scheduling timers for parsing log file...")
-			def read_from_timer():
-				self.sdebug()
-				self.do_read_from_log(logfilename, logfile, session)
-				callLater(10, read_from_timer)
-			callLater(1, read_from_timer)
+			#wrapper class to make an IDelayedCall look like a gio.Cancellable
+			# we only implement cancel() and is_cancelled() as this is all we need here
+			class fake_cancellable_gio(object):
+				def __init__(self, idelayedcall):
+					self.idelayedcall = idelayedcall
+				def is_cancelled(self):
+					return	not self.idelayedcall.active()
+				def cancel(self):
+					self.idelayedcall.cancel()
+			def call_watcher(delay, function_to_call):
+				session.log_watcher = function_to_call
+				idelayedcall = callLater(delay, function_to_call)
+				session.log_watcher_cancel = fake_cancellable_gio(idelayedcall)
+			def read_from_timer(*args):
+				self.sdebug(None, *args)
+				self.read_from_log(logfilename, logfile, session)
+				if session.status!=Session.STATUS_CLOSED:
+					call_watcher(10, read_from_timer)
+			call_watcher(1, read_from_timer)
 
+		#ensure we stop watching for changes when the session ends:
+		def close_session_stop_watching_logfile():
+			self.stop_watching_logfile(session)
+		session.add_status_update_callback(None, Session.STATUS_CLOSED, close_session_stop_watching_logfile, timeout=None)
 		#FIXME: must prevent client application's stdout/stderr from flooding us!
+		session.read_pending = False
 		self.do_read_from_log(logfilename, logfile, session)
 
 
@@ -324,7 +348,7 @@ class	ServerUtilBase(DisplayUtil):
 		giving time for other events to be batched up together.
 		We also ignore messages written after the session is closed.
 		"""
-		if self.debug_log_read:
+		if session.debug_log_read:
 			self.sdebug("read_pending=%s" % session.read_pending, logfilename, logfile, session)
 		if session.read_pending or session.status==Session.STATUS_CLOSED:
 			return	False	#dont run again if running from gobject.io_watch
@@ -333,14 +357,17 @@ class	ServerUtilBase(DisplayUtil):
 		return	True	#keep running if from gobject.io_watch
 
 	def start_read_from_log(self, logfilename, logfile, session):
-		thread.start_new_thread(self.do_read_from_log, (logfilename, logfile, session))
+		t = thread.start_new_thread(self.do_read_from_log, (logfilename, logfile, session))
+		self.sdebug("started thread: %s" % t, logfilename, logfile, session)
 		return False
 
 	def do_read_from_log(self, logfilename, logfile, session):
-		""" this may be called from multiple thread, so use the read_lock """
-		if not self.read_lock.acquire(False):
+		""" this may be called from multiple threads, so use the read_lock """
+		self.sdebug(None, logfilename, logfile, session)
+		if not session.read_lock.acquire(False):
 			self.sdebug("read_lock already held", logfilename, logfile, session)
 			return
+		session.debug_log_read = True
 		try:
 			#FIXME: could get a DoS if the line is very long and consumes memory...
 			BUFSIZE=1024
@@ -348,21 +375,25 @@ class	ServerUtilBase(DisplayUtil):
 				# clear flag since we are about to read until we find the end:
 				session.read_pending = False
 				# raw read:
+				if session.debug_log_read:
+					self.sdebug("about to read, current buffer: %s bytes" % len(session.log_buffer), logfilename, logfile, session)
 				raw = os.read(logfile, BUFSIZE)
+				if session.debug_log_read:
+					self.sdebug("read %s bytes" % len(raw), logfilename, logfile, session)
 				if len(raw)==0:
 					break
 				# append to buffer:
-				data = self.log_buffer+raw
+				data = session.log_buffer+raw
 				lines = data.splitlines(True)
 				last = lines[len(lines)-1]
 				if not (last.endswith('\n') or last.endswith('\r')):
 					""" save the incomplete line in the buffer """
-					self.log_buffer = last
+					session.log_buffer = last
 					lines = lines[:len(lines)-1]
 				else:
 					""" all lines are complete, clear the whole buffer """
-					self.log_buffer = ''
-				if self.debug_log_read:
+					session.log_buffer = ''
+				if session.debug_log_read:
 					self.sdebug("read %s lines" % len(lines), logfilename, logfile, session)
 				self.process_log_data(session, lines)
 				if len(raw)<BUFSIZE and not session.read_pending:
@@ -370,7 +401,7 @@ class	ServerUtilBase(DisplayUtil):
 					break
 			self.poll_server_process(logfilename, session)
 		finally:
-			self.read_lock.release()
+			session.read_lock.release()
 		return session.status!=Session.STATUS_CLOSED					#if running from a timer (has_gio=False), stop when closed
 
 	def process_log_data(self, session, lines):
@@ -382,7 +413,7 @@ class	ServerUtilBase(DisplayUtil):
 		This may be called from threads, so care must be taken in process_log_line()
 		"""
 		sig = msig(session, "%d lines" % len(lines))
-		if self.debug_log_read:
+		if session.debug_log_read:
 			self.debug(sig+" reloading=%s, lines=%s" % (session.reloading, str(lines)))
 		if not lines:
 			return
@@ -392,16 +423,16 @@ class	ServerUtilBase(DisplayUtil):
 			""" this method may be called from another thread - see start_read_from_log """
 			callFromThread(self.update_session_status, session, new_status)
 		for line in lines:
-			if self.last_line and line==self.last_line:
+			if session.last_log_line and line==session.last_log_line:
 				repeated += 1
 				continue
 			if repeated>1:
-				if self.debug_log_read:
+				if session.debug_log_read:
 					self.sdebug("previous line repeated %s times!" % repeated, session, visible_command(csv_list(lines)))
 				repeated = 0
 			try:
 				new_status = self.process_log_line(session, line)
-				if self.debug_log_read:
+				if session.debug_log_read:
 					self.debug(sig+" new status(%s)=%s" % (line, new_status))
 				if not session.reloading and self.update_session_status and new_status:
 					self.log(sig+" setting new status=%s from line=%s" % (new_status, line))
@@ -410,7 +441,7 @@ class	ServerUtilBase(DisplayUtil):
 					last_status = new_status
 			except Exception, e:
 				self.serr("on line=%s" % line, e, session, visible_command(csv_list(lines)))
-			self.last_line = line
+			session.last_log_line = line
 		if session.reloading and last_status and self.update_session_status:
 			self.log(sig+" final new status=%s" % last_status)
 			set_status(last_status)
@@ -454,8 +485,7 @@ class	ServerUtilBase(DisplayUtil):
 		"""
 		Perform any necessary cleanup when a session is closed.
 		"""
-		if session.log_watcher_cancel and not session.log_watcher_cancel.is_cancelled():
-			session.log_watcher_cancel.cancel()				#stop watching the logfile
+		self.stop_watching_logfile(session)
 		if not self.config.delete_session_files:
 			return
 		session_dir = self.get_session_dir(session)
@@ -468,14 +498,17 @@ class	ServerUtilBase(DisplayUtil):
 		if session.pulse_address and session.pulse_address.startswith("unix:"):
 			socket = session.pulse_address[len("unix:"):]
 			if socket.startswith("/tmp/"):			#basic sanity check
-				if is_valid_file(socket):
-					delete_if_exists(socket)
+				self.sdebug("removing socket: %s" % socket)
+				delete_if_exists(socket)
 				pulse_dir = os.path.dirname(socket)
 				if is_valid_dir(pulse_dir) and pulse_dir!="/tmp":
 					try:
+						native_socket_file = os.path.join(pulse_dir, "native")
+						delete_if_exists(native_socket_file)
 						os.rmdir(pulse_dir)
 					except Exception, e:
 						self.serror("failed to remove %s: %s" % (pulse_dir, e), session)
+						self.serror("contents of %s: %s" % (pulse_dir, os.listdir(pulse_dir)))
 
 	def stop_preloaded_sessions(self):
 		for session in self.config.sessions.values():
@@ -492,21 +525,6 @@ class	ServerUtilBase(DisplayUtil):
 		self.sdebug(None, session)
 		self.stop_display(session, None, session.display)
 
-	#***************************************************************************************************
-	# Prelaunch methods
-	def start_prelaunch(self):
-		"""
-		Start a prelaunch session for the user (or users if running in multi-user mode as root)
-		"""
-		if not self.prelaunch_enabled:
-			return
-		if USER_ID>0:
-			self.may_schedule_prelaunch(username=USERNAME)
-		elif len(self.local_users)>0:
-			self.slog("found prelaunch_users=%s" % self.local_users)
-			for username in self.local_users:
-				self.may_schedule_prelaunch(username=username)
-
 	def get_prelaunch_session(self, uuid, username, screen_size, opts):
 		"""
 		Tries to find a compatible pre-launch session.
@@ -515,21 +533,26 @@ class	ServerUtilBase(DisplayUtil):
 		try:
 			self.lock.acquire()
 			for session in self.config.sessions.values():
-				if username!=session.user:
+				if session.session_type != self.session_type:
+					self.sdebug("session %s is not a %s session: %s" % (session, self.session_type, session.session_type), uuid, username, screen_size, opts)
+					continue			#not the right type!
+				if username and username!=session.user:
+					self.sdebug("session %s is already associated with another user: %s" % (session, session.user), uuid, username, screen_size, opts)
 					continue			#in case we run as root
 				if not session.status:
+					self.serror("session %s does not have a status!?" % session, uuid, username, screen_size, opts)
 					continue			#this should never happen!
 				if not session.preload:
+					self.sdebug("session %s is not a preloaded session" % session, uuid, username, screen_size, opts)
 					continue			#not a preload session!
-				if session.session_type != self.session_type:
-					continue			#not the right type!
-				if uuid and session.actor and session.actor!=uuid:
+				if session.actor and (not uuid or session.actor!=uuid):
+					self.sdebug("session %s is already pre-connected to another user: %s" % (session, session.actor), uuid, username, screen_size, opts)
 					continue			#pre-connected to another uuid
-				if session.actor:
-					""" if an actor is set, this means the session is already pre-connected """
+				if not self.is_prelaunched_session_compatible(session, screen_size, opts):
+					self.sdebug("session %s is not compatible" % session, uuid, username, screen_size, opts)
 					continue
-				if self.is_prelaunched_session_compatible(session, screen_size, opts):
-					return session		#OK!
+				self.sdebug("=%s" % session, uuid, username, screen_size, opts)
+				return session		#OK!
 		finally:
 			self.lock.release()
 		return None
@@ -577,20 +600,20 @@ class	ServerUtilBase(DisplayUtil):
 
 
 
-	def	may_schedule_prelaunch(self, delay=5.0, username=USERNAME):
+	def	may_schedule_prelaunch(self, uuid, delay=5.0):
 		"""
 		Schedules a prelaunch session to be started for the user if one does not exist already.
 		"""
-		if not self.prelaunch_enabled or username=="root":	#never pre-launch for root
+		if not self.prelaunch_enabled:
 			return
 		if len(self.clean_prelaunch_failures())>=self.max_prelaunch_failures:
-			self.serr("too many prelaunch failures: %s - not starting any more" % len(self.prelaunch_failures), delay, username)
+			self.serr("too many prelaunch failures: %s - not starting any more" % len(self.prelaunch_failures), uuid, delay)
 			return
-		existing = self.get_prelaunch_session(None, username, None, {})
+		existing = self.get_prelaunch_session(None, uuid, None, {})
 		if not existing:
-			callLater(delay, self.may_start_prelaunch_session, username)
+			callLater(delay, self.may_start_prelaunch_session, uuid)
 		else:
-			self.sdebug("prelaunch session already exists: %s" % existing, delay, username)
+			self.sdebug("prelaunch session already exists: %s" % existing, uuid, delay)
 
 	def clean_prelaunch_failures(self):
 		"""
@@ -601,31 +624,31 @@ class	ServerUtilBase(DisplayUtil):
 		self.prelaunch_failures = [t for t in self.prelaunch_failures if ((now-t)<60*10)]
 		return	self.prelaunch_failures
 
-	def may_start_prelaunch_session(self, username):
+	def may_start_prelaunch_session(self, uuid):
 		"""
 		We re-check that there aren't any prelaunch sessions before starting a new one.
 		(existing ones could have been found on disk during startup)
 		"""
-		existing = self.get_prelaunch_session(None, username, None, {})
+		existing = self.get_prelaunch_session(uuid, None, None, {})
 		if not existing:
-			self.start_prelaunch_session(username)
+			self.start_prelaunch_session(uuid)
 		return	False
 
 
-	def start_prelaunch_session(self, username):
+	def start_prelaunch_session(self, uuid):
 		"""
 		Starts a placeholder session by calling create_prelaunch_session
 		which should be implemented by all subclasses that offer preloading (just return None if not).
 		"""
 		try:
-			session = self.do_start_session(None, username, None, True)
+			session = self.do_start_session(None, uuid, None, True)
 			if session:
-				self.sdebug("saved %s, sending it to clients" % session, username)
+				self.sdebug("saved %s, sending it to clients" % session, uuid)
 				self.add_session(session)
 			else:
-				self.sdebug("session=%s" % session, username)
+				self.sdebug("session=%s" % session, uuid)
 		except Exception, e:
-			self.serr(None, e, username)
+			self.serr(None, e, uuid)
 		return	False			#just run once
 
 
@@ -647,16 +670,18 @@ class	ServerUtilBase(DisplayUtil):
 		self.initialize_session_from_command(session, server_command)
 
 
-	def add_local_user(self, username):
+	def add_local_user(self, username, uuid):
 		"""
 		Used by the server when running in multi-user mode (as root), to tell us about which
 		users are connected (or likely to be connected "preloaded_users") so we can start prelaunch
 		sessions for them.
 		"""
+		self.sdebug(None, username, uuid)
 		if username in self.local_users:
 			return	False
 		self.local_users.append(username)
-		self.may_schedule_prelaunch(1.0, username)
+		if uuid:
+			self.may_schedule_prelaunch(uuid, 1.0)
 		return	True
 
 	def remove_user(self, uuid):
@@ -809,12 +834,13 @@ class	ServerUtilBase(DisplayUtil):
 		self.slog(None, session, user, display)
 		self.kill_display(session, session.server_process_pid)
 
-	def kill_display(self, session, process_pid, sigint=True):
-		self.slog(None, session, process_pid, sigint)
+	def kill_display(self, session, process_pid, kill_signal=signal.SIGTERM):
+		self.slog(None, session, process_pid, kill_signal)
 		if process_pid and process_pid>1 and session.status!=Session.STATUS_CLOSED and kill0(process_pid):
-			kill_pid(process_pid, sigint)
-			if sigint:
-				callLater(5, self.kill_display, session, process_pid, False)			#one last time with SIGKILL...
+			send_kill_signal(process_pid, kill_signal)
+			if kill_signal==signal.SIGTERM:
+				#try one last time with SIGKILL...
+				callLater(5, self.kill_display, session, process_pid, signal.SIGKILL)
 
 	def disconnect(self, session):
 		self.serror("disconnect not supported!", session)
@@ -834,9 +860,8 @@ class	ServerUtilBase(DisplayUtil):
 			if session:
 				""" Sets the session attributes - save will cause it to start """
 				self.prelaunch_start_command(session, server_command, user, screen_size, opts, filenames)
-				self.start_session_wrapper(session)
 				self.add_session(session)
-				self.may_schedule_prelaunch(5.0, user.username)		#in case we used up all the pre-launch
+				self.may_schedule_prelaunch(user.uuid, 5.0)		#in case we used up all the pre-launch
 				return	session
 
 		""" Start a new one """
@@ -864,54 +889,27 @@ class	ServerUtilBase(DisplayUtil):
 	def xauth_enabled(self, session):
 		return	self.is_no_windarwin_no_shadow(session)
 
-	def xmodmap_enabled(self, session, user):
-		return	self.is_no_windarwin_no_shadow(session)
-
-	def set_xmodmap(self, session, user):
-		self.do_set_xmodmap(session, user, False)
-
-	def do_set_xmodmap(self, session, user, use_default=False):
-		if not self.xmodmap_enabled(session, user):
-			self.sdebug("xmodmap is not enabled for this session", session, user, use_default)
-			return
-		self.slog(None, session, user, use_default)
-		session.env = session.get_env()
-		set_xmodmap(session, user, use_default)
-
-	def set_keymap(self, session, user):
-		keymap = user.xkbmap_print
-		self.sdebug("keymap=%s" % visible_command(keymap), session, user)
-		if not keymap:
-			return
-		try:
-			process = subprocess.Popen(["xkbcomp", "-", session.display], stdin=subprocess.PIPE, stdout=subprocess.PIPE)
-			(out,err) = process.communicate(keymap)
-			self.sdebug("xkbcomp out=%s" % visible_command(out))
-			self.sdebug("xkbcomp err=%s" % visible_command(err))
-			returncode = process.poll()
-			if returncode==0:
-				self.slog("xkbcomp successfully applied new keymap", session, user)
-			else:
-				self.serror("xkbcomp failed with exit code %s\n" % returncode, session, user)
-		except Exception, e:
-			self.serr("error setting keymap", e, session, user)
-
 	def set_keyboard_mappings(self, session, user):
-		""" uses set_keymap if we have an xkbmap, set_xmodmap otherwise """
-		if user.xkbmap_print:
-			self.set_keymap(session, user)
+		self.slog(None, session, user)
+		session.env = session.get_env()
+		set_keymap(session.env,
+							user.xkbmap_layout, user.xkbmap_variant,
+							user.xkbmap_print, user.xkbmap_query)
 		self.set_xmodmap(session, user)
 
+	def set_xmodmap(self, session, user):
+		set_xmodmap(session, user)
 
-	def do_start_session(self, user, username, server_command, is_preload=False, screen_size=None, opts=None, filenames=None):
+
+	def do_start_session(self, user, uuid, server_command, is_preload=False, screen_size=None, opts=None, filenames=None):
 		"""
 		Creates a new session, calling start_display(), also starting sound/print,etc
 		user may be null when doing preload
 		"""
-		sig = msig(user, username, server_command, is_preload, screen_size, opts, filenames)
+		sig = msig(user, uuid, server_command, is_preload, screen_size, opts, filenames)
 		self.debug(sig)
 
-		session = self.initialize_new_session(username, server_command, is_preload, screen_size, options=opts)
+		session = self.initialize_new_session(uuid, server_command, is_preload, screen_size, options=opts)
 		def close_session_cleanup():
 			self.session_cleanup(session)
 		session.add_status_update_callback(None, Session.STATUS_CLOSED, close_session_cleanup, timeout=None)
@@ -984,6 +982,7 @@ class	ServerUtilBase(DisplayUtil):
 				if not pid:
 					self.early_failure(session, "failed to start daemon process!")
 					return	False
+				assert pid>0, "invalid pid for %s: %s" % (args, pid)
 				self.session_process_started(pid, session)
 				self.watch_session_log(logfilename, session)
 				self.poll_server_process(logfilename, session)
@@ -1076,7 +1075,7 @@ class	ServerUtilBase(DisplayUtil):
 		if not kill0(pid):
 			self.session_process_ended(pid, "poll failed", session)
 
-	def initialize_new_session(self, username, server_command, is_preload, screen_size, display=None, tcp_port=None, options=None):
+	def initialize_new_session(self, uuid, server_command, is_preload, screen_size, display=None, tcp_port=None, options=None):
 		"""
 		Allocates a display, initializes host/port, ID, password, ..
 		"""
@@ -1103,14 +1102,16 @@ class	ServerUtilBase(DisplayUtil):
 		session.requires_tunnel = tunnel
 		session.password = self.new_password()
 		session.xauth_cookie = session.password				#needs to be identical to password for NX! VNC will change and encrypt the password and won't use xauth..
-		session.user = username
+		session.user = USERNAME
+		session.owner = uuid
 		session.status = Session.STATUS_STARTING
 		session.preload = is_preload
 		session.screen_size = screen_size
 		session.session_type = self.session_type
 		session.start_time = int(time.time())
 		session.env = session.get_env()
-		self.sdebug("=%s" % session, username, server_command, is_preload, screen_size, display, tcp_port)
+		session.debug_log_read = self.debug_log_read
+		self.sdebug("=%s" % session, uuid, server_command, is_preload, screen_size, display, tcp_port)
 		return	session
 
 	def initialize_session_from_command(self, session, server_command):
@@ -1248,7 +1249,7 @@ class	ServerUtilBase(DisplayUtil):
 		try:
 			env = session.get_env()
 			from winswitch.server.xdg_open import WSW_XDG_OPEN
-			self.slog("XDG_OPEN_COMMAND=%s, WSW_XDG_OPEN=%s, valid exe=%s" % (XDG_OPEN_COMMAND, WSW_XDG_OPEN, is_valid_exe(XDG_OPEN_COMMAND)))
+			self.sdebug("XDG_OPEN_COMMAND=%s, WSW_XDG_OPEN=%s, valid exe=%s" % (XDG_OPEN_COMMAND, WSW_XDG_OPEN, is_valid_exe(XDG_OPEN_COMMAND)))
 			if is_valid_exe(XDG_OPEN_COMMAND) and is_valid_file(WSW_XDG_OPEN) and XDG_OPEN_COMMAND.find("winswitch")<0:
 				env["WSW_XDG_OPEN"] = WSW_XDG_OPEN
 				env["WSW_ORIGINAL_XDG_OPEN"] = XDG_OPEN_COMMAND
@@ -1259,6 +1260,8 @@ class	ServerUtilBase(DisplayUtil):
 			from winswitch import __version__
 			env["WINSWITCH_SERVER"] = __version__
 			env["_WINSWITCH_SERVER_PID"] = "%s" % os.getpid()
+			#apparently this fixes Qt/KDE performance in some cases:
+			env["QT_GRAPHICSSYSTEM"] = "native"
 			self.sdebug("args=%s, env=%s, session_file=%s" % (csv_list(args), env, session_file), session)
 			self.save_session(session)
 			proc = subprocess.Popen(args, stdin=None, stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=env)
@@ -1387,6 +1390,16 @@ class	ServerUtilBase(DisplayUtil):
 		if self.disable_gnome_screensaver:
 			""" No rush: this can run a little while later: """
 			callLater(10, self.do_disable_gnome_screensaver, session)
+		if self.disable_xscreensaver and is_valid_exe(XSCREENSAVER_COMMAND_COMMAND):
+			callLater(10, self.do_disable_xscreensaver, session)
+
+	def do_disable_xscreensaver(self, session):
+		if session.status==Session.STATUS_CLOSED:
+			self.slog("session already closed (failed?)", session)
+			return
+		self.sdebug(None, session)
+		cmd = [XSCREENSAVER_COMMAND_COMMAND, "-exit"]
+		exec_nopipe(cmd, env=session.get_env())
 
 	def do_disable_gnome_screensaver(self, session):
 		if session.status==Session.STATUS_CLOSED:
@@ -1567,8 +1580,9 @@ DefaultPolicy default
 			session.gst_clone_plugin = ""
 			session.gst_clone_plugin_options = {}
 			#session.add_status_update_callback(self, from_status, to_status, callback, clear_it=True, timeout=30):
-			callback = lambda : self.disconnect_sound_client(session)
-			session.do_add_status_update_callback([Session.STATUS_CONNECTED,Session.STATUS_IDLE], [Session.STATUS_SUSPENDING,Session.STATUS_SUSPENDED], callback, clear_it=True, timeout=None)
+			def suspend_stop_sound(*args):
+				self.disconnect_sound_client(session)
+			session.do_add_status_update_callback([Session.STATUS_CONNECTED,Session.STATUS_IDLE], [Session.STATUS_SUSPENDING,Session.STATUS_SUSPENDED], suspend_stop_sound, clear_it=True, timeout=None)
 
 
 	def disconnect_sound_client(self, session):
