@@ -587,9 +587,7 @@ class	VirtualboxServerUtil(ServerUtilBase):
 
 
 
-def main():
-	from winswitch.util.main_loop import loop_init, loop_run, loop_exit
-	loop_init(False)
+def detect():
 	from winswitch.util.simple_logger import Logger
 	logger=Logger("virtualbox_server_util", log_colour=Logger.CYAN)
 	from winswitch.util.config import get_local_server_config
@@ -602,10 +600,14 @@ def main():
 		logger.slog(None, *args)
 	def session_failed(*args):
 		logger.slog(None, *args)
-	vbsu = VirtualboxServerUtil(config, add_session, remove_session, update_session_status, session_failed)
-	vbsu.detect_existing_sessions([])
-	callLater(10, loop_exit)
-	loop_run()
+	def detect():
+		vbsu = VirtualboxServerUtil(config, add_session, remove_session, update_session_status, session_failed)
+		vbsu.detect_existing_sessions([])
+
+def main():
+	from winswitch.util.main_loop import test_loop
+	test_loop(detect)
+
 
 if __name__ == "__main__":
 	main()
