@@ -7,7 +7,6 @@
 import gtk
 import sys
 
-from winswitch.consts import SPEED_NAMES, DEFAULT_LAN_SPEED
 from winswitch.util.common import get_bool
 from winswitch.globals import WIN32, OSX
 from winswitch.virt.xpra_client_base import XpraClientBase
@@ -22,46 +21,24 @@ ADAPTIVE_BANDWIDTH = True
 
 class	XpraClientUtil(XpraClientBase, ClientOptionsBase):
 
-	LOSSY_10 = "JPEG lowest quality (10%)"
-	LOSSY_25 = "JPEG low quality (25%)"
-	LOSSY_50 = "JPEG average quality (50%)"
-	LOSSY_90 = "JPEG best lossy quality (90%)"
-
-	JPEG_COMPRESSION_OPTIONS = [LOSSY_10, LOSSY_25, LOSSY_50, LOSSY_90]
-	JPEG_COMPRESSION_OPTIONS_PAIRS = [
-							(LOSSY_10, 10),
-							(LOSSY_25, 25),
-							(LOSSY_50, 50),
-							(LOSSY_90, 90)
-							]
-
 	def	__init__(self, update_session_status, notify_callback):
 		XpraClientBase.__init__(self, update_session_status, notify_callback)
 
-
 	def get_encoding_options(self, server):
 		""" returns the list of encoding options """
 		options = []
 		if not server.supports_xpra_encodings:
 			return	options
 		if "png" in server.supports_xpra_encodings:
-			options.append(("PNG compression (lossless)", "png"))
+			options.append(("PNG (lossless)", "png"))
 		if "rgb24" in server.supports_xpra_encodings:
-			options.append(("No compression (raw)", "rgb24"))
+			options.append(("RGB24+ZLIB (lossless)", "rgb24"))
 		if "x264" in server.supports_xpra_encodings:
-			options.append(("x264 video compression (lossy)", "x264"))
+			options.append(("x264 video (lossy)", "x264"))
 		if "vpx" in server.supports_xpra_encodings:
-			options.append(("vpx video compression (lossy)", "vpx"))
+			options.append(("vpx video (lossy)", "vpx"))
 		if "jpeg" in server.supports_xpra_encodings:
-			for name, value in XpraClientUtil.JPEG_COMPRESSION_OPTIONS_PAIRS:
-				options += [(name, "jpeg:%s" % value)]
-			if ADAPTIVE_BANDWIDTH:
-				speeds = SPEED_NAMES.keys()		#list of speeds in bytes per second
-				speeds.sort()
-				for speed in speeds:
-					if speed>server.line_speed or speed>=DEFAULT_LAN_SPEED:
-						break
-					options += [("JPEG adaptive - %s" % SPEED_NAMES.get(speed), "jpeg:%s" % (-speed/1000))]
+			options.append(("JPEG (lossy)", "jpeg"))
 		return	options
 
 	def get_encoding_widget(self, server, server_command, current_options, change_cb, shown=True):
