@@ -62,13 +62,6 @@ class	XpraServerUtil(ServerUtilBase):
 	def xauth_enabled(self, session):
 		return	False		#not required
 
-	def can_capture(self, session):
-		#old versions of xpra did not support screenshots:
-		if not self.config.xpra_version:
-			return False
-		numver = [int(x) for x in self.config.xpra_version.split(".")]
-		return numver>=[0, 0, 7, 35]
-	
 	def can_capture_now(self, session):
 		#the session must be connected:
 		return session.status in [Session.STATUS_CONNECTED, Session.STATUS_IDLE]
@@ -349,7 +342,7 @@ class	XpraServerUtil(ServerUtilBase):
 				self.sdebug("unmapped display ignored", state, display)
 				return	None
 			elif not self.capture_external_sessions:
-				self.serror("found session - but no details on disk... ignoring it", state, display)
+				self.slog("found session - but no details on disk... ignoring it", state, display)
 				self.ignored_displays.append(display)
 				return	None
 			#create a new session object:
